# Table of Contents

- [interfaces-modeling-v3](<./interfaces-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Interfaces (Meta Model v3)](<./Modeling-Interfaces-Meta-Model-v3.md>)
  - [Overview](<./Modeling-Interfaces-Meta-Model-v3/Overview.md>)
  - [Dataflow vs. Provider / Consumer](<./Modeling-Interfaces-Meta-Model-v3/Dataflow-vs.-Provider--Consumer.md>)
  - [Why is there only one provider application?](<./Modeling-Interfaces-Meta-Model-v3/Why-is-there-only-one-provider-application.md>)
  - [How do I model interface technology?](<./Modeling-Interfaces-Meta-Model-v3/How-do-I-model-interface-technology.md>)
  - [Interface Attributes](<./Modeling-Interfaces-Meta-Model-v3/Interface-Attributes.md>)
  - [Was this page helpful?](<./Modeling-Interfaces-Meta-Model-v3/Was-this-page-helpful.md>)
